﻿using Microsoft.SPOT.Hardware;
using Mountaineer.Netmf.Hardware;
using Oberon.Net;
using Oberon.Net.SocketStreams;
using Oberon.Yaler;

namespace Configuration
{
    public static class Parameters
    {
        // parameters for I/O ports specific to the used hardware
        public static Cpu.Pin LedPin;
        public static Cpu.Pin ButtonPin;
        public static Cpu.Pin LowPin;
        public static Cpu.Pin HighPin;
        public static Cpu.AnalogChannel AnalogPin;
        // connect the potentiometer as described in the book on pages 22 to 25

        // parameters for Xively samples
        // check at https://xively.com/feeds/<insert_your_Xively_feed_ID_here>
        public static string ApiKey;
        public static string FeedId;

        // parameters for server samples
        public static string RelayDomain;
        static string RelaySecretKey;
        public static IServerStreamProvider StreamProvider;

        public static void Setup()
        {
            LedPin = OnboardIO.LedRed;
            ButtonPin = OnboardIO.Button;
            LowPin = Socket5.Pin6;      // dummy, not needed on Gadgeteer, don't connect anything to socket 5
            HighPin = Socket5.Pin8;     // dummy, not needed on Gadgeteer, don't connect anything to socket 5
            AnalogPin = Socket6.AnalogInput3;

            ApiKey = "<insert your API key here>";
            FeedId = "<insert your feed ID here>";
            // check at https://xively.com/feeds/<FeedId>

            RelayDomain = "<insert your relay domain here>";
            RelaySecretKey = "<insert your secret key here>";

            if (RelayDomain == null)
            {
                StreamProvider = new SocketServerStreamProvider(80);
            }
            else
            {
                IClientStreamProvider clientStreamFactory = new SocketClientStreamProvider();
                StreamProvider = new YalerServerStreamProvider(clientStreamFactory, RelayDomain, RelaySecretKey);
            }
        }
    }
}
